<?php
/*
Plugin Name: Stepbox
Plugin URI: http://thestepbox.com/
Description: This plugin allows you to monetize your members area's and download pages by leveraging our proven 3 step system. Use it to promote any of our high converting "My Unfair Advantage" offers or webinars OR you can use it to promote your own stuff as well. 
Author: Omar & Melinda Martin, Higher Level Strategies, Inc.
Version: 1.4
Author URI: http://higherlevelstrategies.com/
Help URI: http://hlshelpdesk.com/
*/

global $wpdb;

define('STEPBOX_VERSION', '1.4');
define('STEPBOX_MAIN_TABLE', $wpdb->prefix . "stepbox_main");
define('STEPBOX_BONUS_TABLE', $wpdb->prefix . "stepbox_bonus");
define('STEPBOX_PLUGIN_DIR', plugin_dir_path( __FILE__ )); 
define('STEPBOX_PLUGIN_URL', plugin_dir_url( __FILE__ ));

global $stepbox_db_version;
$stepbox_db_version = '1.4';

// Save the registration data if necessary
stepbox_save_reg();

// Return the preview data if requested
stepbox_preview_data();

require 'plugin-updates/plugin-update-checker.php';
$stepboxUpdateChecker = PucFactory::buildUpdateChecker(
	'http://thestepbox.com/download/stepbox_info.json',
	__FILE__,
	'stepbox_update_check'
);

//Here's how you can add query arguments to the URL.
function addSecretKey($query){
	$query['secret'] = 'stepbox_secret';
	return $query;
}
$stepboxUpdateChecker->addQueryArgFilter('addSecretKey');

add_action( 'admin_menu', 'stepbox_menu' );
add_action( 'admin_init', 'stepbox_load_admin_config');
add_action( 'plugins_loaded', 'stepbox_update_db_check' );

// Activation hook
register_activation_hook( __FILE__, 'stepbox_activate' );

// Deactivation hook for development
//register_deactivation_hook( __FILE__, 'stepbox_deactivate_debug' );

// Load the necessary scripts and css files for the admin page.
function stepbox_load_admin_config() {
	wp_enqueue_script( 'jquery');
	wp_enqueue_style( 'step-box-style', plugins_url( 'stepbox/css/style.css' ) );

	wp_register_script( 'jquery-ui', plugins_url( 'stepbox/js/jquery-ui/jquery-ui.js'), array('jquery'));
	wp_enqueue_script( 'jquery-ui');
	wp_enqueue_style( 'jquery-ui-style', plugins_url('stepbox/js/jquery-ui/jquery-ui.css' ) );
	
	wp_register_script( 'stepbox-fancybox', plugins_url( 'stepbox/js/fancybox/jquery.fancybox.js'), array('jquery'));
	wp_enqueue_script( 'stepbox-fancybox');
	wp_register_script( 'stepbox-fancybox-btns', plugins_url( 'stepbox/js/fancybox/helpers/jquery.fancybox-buttons.js'), array('jquery'));
	wp_enqueue_script( 'stepbox-fancybox-btns');
	wp_enqueue_style( 'stepbox-fancybox-style', plugins_url('stepbox/js/fancybox/jquery.fancybox.css' ) );
	wp_enqueue_style( 'stepbox-fancybox-btns-style', plugins_url('stepbox/js/fancybox/helpers/jquery.fancybox-buttons.css' ) );

	wp_register_script( 'stepbox-colorpicker', plugins_url( 'stepbox/js/color_picker/js/colpick.js'), array('jquery'));
	wp_enqueue_script( 'stepbox-colorpicker');
	wp_enqueue_style( 'stepbox-colorpicker', plugins_url('stepbox/js/color_picker/css/colpick.css' ) );
}

// Stepbox menu and admin page
function stepbox_menu() 
{
	global $submenu;
	add_menu_page( 'Stepbox Admin Page', 'Stepbox', 'manage_options', 'stepbox', 'stepbox_admin_page'); 
}
function stepbox_admin_page() 
{
       include('templates/stepbox-admin-page.php'); 
}

// Activation 
function stepbox_activate () {
	global $wpdb;
	global $stepbox_db_version;

	$charset_collate = '';

	if ( ! empty( $wpdb->charset ) ) {
		$charset_collate = "DEFAULT CHARACTER SET {$wpdb->charset}";
	}

	if ( ! empty( $wpdb->collate ) ) {
		$charset_collate .= " COLLATE {$wpdb->collate}";
	}

	// Table to store the main stepbox data
	$table_name = STEPBOX_MAIN_TABLE; 
	
	$sql = "CREATE TABLE $table_name (
	id int(9) NOT NULL AUTO_INCREMENT,
	stepbox_name varchar(100) DEFAULT NULL,
	stepbox_title varchar(255) DEFAULT 'Start Here - Please Follow These Steps First',
	stepbox_code varchar(100) DEFAULT NULL,
	stepbox_layout varchar(20) DEFAULT 'horizontal',
	stepbox_options text NOT NULL,
	step1_title varchar(255) DEFAULT 'Step 1: Whitelist Our Email Address',
	step1_icon_image varchar(255) DEFAULT NULL,
	step1_button_image varchar(255) DEFAULT NULL,
	step1_desc text DEFAULT NULL,
	step2_title varchar(255) DEFAULT 'Step 2: Register for Bonus Live Training',
	step2_icon_image varchar(255) DEFAULT NULL,
	step2_button_image varchar(255) DEFAULT NULL,
	step2_desc text DEFAULT NULL,
	step3_title varchar(255) DEFAULT 'Step 3: Join Us in the Facebook Group',
	step3_icon_image varchar(255) DEFAULT NULL,
	step3_button_image varchar(255) DEFAULT NULL,
	step3_desc text DEFAULT NULL,
	bonus_id INT(11) DEFAULT NULL, 
	email varchar(255) DEFAULT NULL,
	email_type varchar(20) DEFAULT 'default',
	email_page_id INT(11) DEFAULT NULL, 
	fb_url varchar(255) DEFAULT NULL,
	custom_bonus_url varchar(255) DEFAULT NULL,
	stepbox_status varchar(10) DEFAULT 'inactive',
	created_date timestamp NULL DEFAULT NULL,
	updated_date timestamp NULL DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP,
	PRIMARY KEY (`id`)
	) $charset_collate;
	";

	require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
	dbDelta($sql);
	
	// Table to store the bonus data for step2
	$table_name = STEPBOX_BONUS_TABLE; 
	
	$sql = "CREATE TABLE $table_name (
	id int(9) NOT NULL AUTO_INCREMENT,
	external_id int(9) NOT NULL,
	external_type varchar(20) DEFAULT 'jvzoo',
	bonus_title varchar(255) DEFAULT NULL,
	bonus_url varchar(255) DEFAULT NULL,
	bonus_desc text DEFAULT NULL,
	bonus_status varchar(10) DEFAULT 'active',
	approved tinyint(1) DEFAULT '0',
	created_date timestamp NULL DEFAULT NULL,
	updated_date timestamp NULL DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP,
	PRIMARY KEY (`id`),
	UNIQUE KEY `bonus_data` (`external_id`,`external_type`),
	KEY `bonus_status` (`bonus_status`)
	) $charset_collate;
	";

	require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
	dbDelta($sql);
	
	add_option( "stepbox_db_version", "$stepbox_db_version" );
	
	// Default data 
	$filename = STEPBOX_PLUGIN_DIR . 'data/bonus_data.json';
	if(file_exists($filename)) {
		$f = fopen($filename, 'r');
		$json = fread($f, filesize($filename));
		fclose($f);
		$sb_bonus = json_decode($json);
	
		// Activate or update data
		$now = date('Y-m-d H:i:s');
		foreach($sb_bonus as $key=>$val) {
			// Check for the existing data
			$bonus_id = $wpdb->get_var("SELECT id FROM $table_name WHERE external_id='$key' AND external_type='{$val[0]}'");
			if($bonus_id) {
				$wpdb->update( 
				$table_name, 
				array( 
					'bonus_url' => $val[1],
					'bonus_title'=>$val[2],
					'bonus_desc'=>$val[3],
					) ,
				array(
					'id' => $bonus_id
					)
				);
			} else {
				$wpdb->insert( 
				$table_name, 
				array( 
					'external_id' => $key, 
					'external_type' => $val[0],
					'bonus_url' => $val[1],
					'bonus_title'=>$val[2],
					'bonus_desc'=>$val[3],
					'bonus_status'=>'active',
					'created_date'=>$now,
					) 
				);
			}
		}
	}
	
	// Deactivate data if needed
	$filename = STEPBOX_PLUGIN_DIR . 'data/bonus_data_deactivate.json';
	if(file_exists($filename)) {
		$f = fopen($filename, 'r');
		$json = fread($f, filesize($filename));
		fclose($f);
		$sb_bonus = json_decode($json);
	
		foreach($sb_bonus as $key=>$val) {
			$wpdb->query("
				UPDATE $table_name
				SET bonus_status = 'inactive'
				WHERE external_id=$key AND external_type='{$val[0]}'
			");
		}
	}
	$saved_max = $wpdb->get_var("SELECT MAX(id) FROM " . STEPBOX_MAIN_TABLE);
	for($i=1; $i<=$saved_max; $i++) {
		$data = $wpdb->get_row("SELECT * FROM " . STEPBOX_MAIN_TABLE . " WHERE id=" . $i, ARRAY_A);
		if($data) {
			$json = json_encode($data);
			delete_option('stepbox_preview_' . $i);
			add_option('stepbox_preview_' . $i, $json);
		}
	}
	
	// Whitelist email page
	$whitelist_page = get_option('stepbox_whitelist_page');
	$filename = STEPBOX_PLUGIN_URL . 'data/whitelist.php';
	update_option('stepbox_whitelist_page', $filename);
}

function stepbox_deactivate_debug() 
{
	global $wpdb;
	global $stepbox_db_version;
	
	$table = STEPBOX_MAIN_TABLE;      
	$wpdb->query("DROP TABLE IF EXISTS $table");
	$table = STEPBOX_BONUS_TABLE;      
	$wpdb->query("DROP TABLE IF EXISTS $table");
	
	delete_option("stepbox_db_version", $stepbox_db_version);
}

function stepbox_update_db_check() {
	global $stepbox_db_version;
	if ( get_site_option( 'stepbox_db_version' ) != $stepbox_db_version ) {
		stepbox_activate();
	}
}

// Shortcode [stepbox id="xxx"]
function stepbox_shortcode_handler($atts, $content = null ) {
	$a = shortcode_atts( array(
		'id' => 'default',
	), $atts );
   
	global $wpdb;
	$stepbox = $wpdb->get_row("SELECT * FROM ". STEPBOX_MAIN_TABLE . " WHERE stepbox_code='{$a['id']}'", ARRAY_A);
	$stepbox['registered'] = stepbox_registered();

	ob_start();
	include('templates/stepbox-main.php'); 
	$output = ob_get_clean();
	return $output;
}
add_shortcode('stepbox', 'stepbox_shortcode_handler');

// Check if the user has submitted aweber form
function stepbox_registered() {
	$json = get_option('stepbox_registration_data');
	$registered = false;
	if($json) {
		$reg_data = json_decode($json, true);
		if($reg_data['jvzoo_id']) {
			$registered = $reg_data;
		}
	}
	return $registered;
}

// Save the registration form if submitted
function stepbox_save_reg() {
	// Registration form submitted
	if(isset($_POST['stepbox_agreement'])) {
		$reg_required = array(
			'email', 'first', 'last', 'company', 'street1', 'city', 'zip', 'phone', 'skype','jvzoo_id','main_url', 'state'
		);
		$reg_optional = array(
			'street2'
		);
		$reg_data_save = array();
		$valid = true;
		foreach($reg_required as $val) {
			if($_POST[$val]) {
				$reg_data_save[$val] = $_POST[$val];
			} else {
				$valid = false;
			}
		}
		foreach($reg_optional as $val) {
			if($_POST[$val]) {
				$reg_data_save[$val] = $_POST[$val];
			}
		}
	
		if($valid) {
			$json = json_encode($reg_data_save);
			$reg_existing = get_option('stepbox_registration_data');
			if($reg_existing) {
				delete_option('stepbox_registration_data');
			}
			add_option('stepbox_registration_data', $json);
			echo '1';
		
		} else {
			echo '0';
		}
		exit;
	} 
	return;
}
	
// Preview data
function stepbox_preview_data() {
	global $wpdb;
	if(isset($_POST['sb_preview'])) {
		$json = get_option('stepbox_preview_' . $_POST['stepbox_id']);
		if($json) {
			$stepbox = json_decode($json, true);
		}
		$stepbox['registered'] = stepbox_registered();
		include('templates/stepbox-main.php'); 
		exit;
	}
	return;
}

// Generate a new whitelist page
function stepbox_create_email_page($email_data, $email_img) {
	ob_start();
	include('templates/stepbox-whitelist.php'); 
	$content = ob_get_clean();
	
	$new_post = array(
		'comment_status' => 'closed',
		'ping_status' =>  'closed' ,
		'post_author' => 1,
		'post_date' => date('Y-m-d H:i:s'),
		//'post_name' => 'How To Whitelist Our Email Address',
		'post_status' => 'publish' ,
		'post_title' => $_POST['sb_email_page_title'],
		'post_type' => 'page',
		'post_content' => $content,
	);  
	$newid = wp_insert_post($new_post, false );
	return $newid;
}


?>
